import { CalendarInputDateProps } from '../CalendarInputDate/types';
import { CalendarInputTimeProps } from '../CalendarInputTime/types';
import { FromToRange } from '../commonTypes';
import { ExtractPropTypes, PropType } from 'vue';
import { InitialDate } from '../../composables/useSelectedDates';
import { Nullable } from '../../utils/helpers';
import { DatesAvailabilityConfig } from '../../composables/useCalendarDateUtil';
export type HelperButtonShape = Readonly<{
    name: string;
} & FromToRange<Date>>;
export type CalendarDialogInputTimeProps = Partial<Pick<CalendarInputTimeProps, "inputClass" | "readonly" | "step">>;
export type CalendarDialogInputDateProps = Partial<Pick<CalendarInputDateProps, "format" | "inputClass"> & {
    labelStarts: string;
    labelEnds: string;
}>;
export declare const calendarDialogProps: {
    language: {
        type: PropType<string>;
        default: string;
    };
    disabledDates: {
        type: PropType<DatesAvailabilityConfig>;
        validator: (value: DatesAvailabilityConfig | undefined | null) => boolean;
        default: () => Partial<{
            dates: Array<Date>;
            ranges: Array<FromToRange<Date>>;
            custom: import('../../composables/useCalendarDateUtil').DisableDateCheckFunction;
        } & FromToRange<Date>>;
    };
    availableDates: {
        type: PropType<DatesAvailabilityConfig>;
        validator: (value: DatesAvailabilityConfig | undefined | null) => boolean;
        default: () => Partial<{
            dates: Array<Date>;
            ranges: Array<FromToRange<Date>>;
            custom: import('../../composables/useCalendarDateUtil').DisableDateCheckFunction;
        } & FromToRange<Date>>;
    };
    isMondayFirst: {
        type: PropType<boolean>;
        default: boolean;
    };
    initialDates: {
        type: PropType<InitialDate>;
        validator: (value: InitialDate | undefined | null) => boolean;
        default: () => InitialDate;
    };
    inline: {
        type: PropType<boolean>;
        default: boolean;
    };
    showHelperButtons: {
        type: PropType<boolean>;
        default: boolean;
    };
    helperButtons: {
        type: PropType<Array<HelperButtonShape>>;
        validator: (value: Array<HelperButtonShape> | undefined | null) => boolean;
        default: () => Array<HelperButtonShape>;
    };
    timeInput: {
        type: PropType<CalendarDialogInputTimeProps>;
        default: () => Partial<Pick<{
            inputClass?: unknown;
            readonly?: unknown;
            timestamp?: unknown;
            language?: unknown;
            step?: unknown;
        } & {
            language: string;
            timestamp: number;
            readonly: boolean;
            step: number;
        } & {
            inputClass?: import('../commonTypes').ClassValue;
        }, "inputClass" | "readonly" | "step">>;
    };
    dateInput: {
        type: PropType<CalendarDialogInputDateProps>;
        default: () => Partial<Pick<{
            inputClass?: unknown;
            timestamp?: unknown;
            format?: unknown;
            language?: unknown;
        } & {
            language: string;
            timestamp: number;
            format: string;
        } & {
            inputClass?: import('../commonTypes').ClassValue;
        }, "inputClass" | "format"> & {
            labelStarts: string;
            labelEnds: string;
        }>;
    };
    switchButtonLabel: {
        type: PropType<string>;
        default: string;
    };
    switchButtonInitial: {
        type: PropType<boolean>;
        default: boolean;
    };
    applyButtonLabel: {
        type: PropType<string>;
        default: string;
    };
    resetButtonLabel: {
        type: PropType<string>;
        default: string;
    };
};
export type CalendarDialogProps = ExtractPropTypes<typeof calendarDialogProps>;
export declare const calendarDialogEmits: import('../../utils/helpers').InferRecord<{
    "on-apply": (_startDate: Date, _endDate: Date) => boolean;
    "on-reset": (_e: Event) => boolean;
    "select-date": (_startDate: Nullable<Date>, _endDate: Nullable<Date>) => boolean;
    "select-disabled-date": (_date: Date) => boolean;
    "on-prev-calendar": (_e: Event) => boolean;
    "on-next-calendar": (_e: Event) => boolean;
}>;
export type CalendarDialogEmits = typeof calendarDialogEmits;
