import { DateInputProps } from '../DateInput/types';
import { InitialDate } from '../../composables/useSelectedDates';
import { Nullable } from '../../utils/helpers';
import { ExtractPropTypes, PropType } from 'vue';
export type DatePickerDateInputProps = Partial<Pick<DateInputProps, "inputClass" | "refName" | "name" | "placeholder" | "id" | "required">>;
export type DatePickerModelValue = InitialDate | null;
export declare const datePickerProps: {
    modelValue: {
        type: PropType<DatePickerModelValue>;
        default: () => null;
    };
    initialDates: {
        type: PropType<InitialDate>;
        validator: (value: InitialDate | undefined | null) => boolean;
        default: () => InitialDate;
    };
    inline: {
        type: PropType<boolean>;
        default: boolean;
    };
    language: {
        type: PropType<string>;
        default: string;
    };
    format: {
        type: PropType<string>;
        default: string;
    };
    sameDateFormat: {
        type: PropType<import('../DateInput/types').SameDateFormatConfig>;
        validator: (value: import('../DateInput/types').SameDateFormatConfig | undefined | null) => boolean;
        default: () => import('../DateInput/types').SameDateFormatConfig;
    };
    dateInput: {
        type: PropType<DatePickerDateInputProps>;
        default: () => Partial<Pick<{
            inputClass?: unknown;
            refName?: unknown;
            name?: unknown;
            type?: unknown;
            placeholder?: unknown;
            id?: unknown;
            required?: unknown;
            format?: unknown;
            sameDateFormat?: unknown;
            language?: unknown;
            selectedStartDate?: unknown;
            selectedEndDate?: unknown;
        } & {
            language: string;
            format: string;
            sameDateFormat: import('../DateInput/types').SameDateFormatConfig;
        } & {
            inputClass?: import('../commonTypes').ClassValue;
            type?: string | undefined;
            required?: boolean | undefined;
            name?: string | undefined;
            refName?: string | undefined;
            placeholder?: string | undefined;
            id?: string | undefined;
            selectedStartDate?: Nullable<Date> | undefined;
            selectedEndDate?: Nullable<Date> | undefined;
        }, "inputClass" | "required" | "name" | "refName" | "placeholder" | "id">>;
    };
    disabledDates: {
        type: PropType<import('../..').DatesAvailabilityConfig>;
        validator: (value: import('../..').DatesAvailabilityConfig | undefined | null) => boolean;
        default: () => Partial<{
            dates: Array<Date>;
            ranges: Array<import('../commonTypes').FromToRange<Date>>;
            custom: import('../../composables/useCalendarDateUtil').DisableDateCheckFunction;
        } & import('../commonTypes').FromToRange<Date>>;
    };
    availableDates: {
        type: PropType<import('../..').DatesAvailabilityConfig>;
        validator: (value: import('../..').DatesAvailabilityConfig | undefined | null) => boolean;
        default: () => Partial<{
            dates: Array<Date>;
            ranges: Array<import('../commonTypes').FromToRange<Date>>;
            custom: import('../../composables/useCalendarDateUtil').DisableDateCheckFunction;
        } & import('../commonTypes').FromToRange<Date>>;
    };
    showHelperButtons: {
        type: PropType<boolean>;
        default: boolean;
    };
    helperButtons: {
        type: PropType<Array<import('../CalendarDialog/types').HelperButtonShape>>;
        validator: (value: Array<import('../CalendarDialog/types').HelperButtonShape> | undefined | null) => boolean;
        default: () => Array<import('../CalendarDialog/types').HelperButtonShape>;
    };
    calendarDateInput: {
        type: PropType<import('../CalendarDialog/types').CalendarDialogInputDateProps>;
        default: () => Partial<Pick<{
            inputClass?: unknown;
            timestamp?: unknown;
            format?: unknown;
            language?: unknown;
        } & {
            language: string;
            timestamp: number;
            format: string;
        } & {
            inputClass?: import('../commonTypes').ClassValue;
        }, "inputClass" | "format"> & {
            labelStarts: string;
            labelEnds: string;
        }>;
    };
    calendarTimeInput: {
        type: PropType<import('../CalendarDialog/types').CalendarDialogInputTimeProps>;
        default: () => Partial<Pick<{
            inputClass?: unknown;
            readonly?: unknown;
            timestamp?: unknown;
            language?: unknown;
            step?: unknown;
        } & {
            language: string;
            timestamp: number;
            readonly: boolean;
            step: number;
        } & {
            inputClass?: import('../commonTypes').ClassValue;
        }, "inputClass" | "readonly" | "step">>;
    };
    switchButtonLabel: {
        type: PropType<string>;
        default: string;
    };
    switchButtonInitial: {
        type: PropType<boolean>;
        default: boolean;
    };
    applyButtonLabel: {
        type: PropType<string>;
        default: string;
    };
    resetButtonLabel: {
        type: PropType<string>;
        default: string;
    };
    isMondayFirst: {
        type: PropType<boolean>;
        default: boolean;
    };
};
export type DatePickerProps = ExtractPropTypes<typeof datePickerProps>;
export declare const datePickerEmits: import('../../utils/helpers').InferRecord<{
    "update:model-value": (_modelValue: DatePickerModelValue) => boolean;
    "date-applied": (_startDate: Date, _endDate: Date) => boolean;
    "datepicker-opened": () => boolean;
    "datepicker-closed": () => boolean;
    "on-prev-calendar": (_e: Event) => boolean;
    "on-next-calendar": (_e: Event) => boolean;
    "select-date": (_startDate: Nullable<Date>, _endDate: Nullable<Date>) => boolean;
    "select-disabled-date": (_date: Date) => boolean;
    "on-reset": (_e: Event) => boolean;
}>;
export type DatePickerEmits = typeof datePickerEmits;
